@@ -54,7 +54,7 @@
 #define CWIO_DEBUG
 
 Cserial *cwio_serial = 0;
-Cmorse  *morse = 0;
+cMorse  *morse = 0;
 
 static pthread_t       cwio_pthread;
 static pthread_cond_t  cwio_cond;
@@ -70,9 +70,23 @@ std::string cwio_text;
 //======================================================================
 // sub millisecond accurate sleep function
 // sleep_time in seconds
-
+//======================================================================
 extern double monotonic_seconds();
 
+//======================================================================
+// QMX / QMX+ keyer commands
+//======================================================================
+void QMX_send_char(int c);
+void set_QMX_keyer();
+void QMX_sleep(double secs);
+double QMX_now();
+
+//======================================================================
+// GPIO keyer command
+//======================================================================
+void send_gpio_CW(int c);
+
+
 #ifdef CWIO_DEBUG
 FILE *fcwio = (FILE *)0;
 FILE *fcwio2 = (FILE *)0;
@@ -144,6 +158,15 @@ double start_at2;
 
 void send_cwkey(char c)
 {
+
+#if USE_LIBGPIOD
+	if ((progStatus.gpio_cw_line != -1) && progStatus.enable_gpio_cw ) {
+		return send_gpio_CW(c);
+	}
+#endif
+
+	if (selrig->name_ == rig_qmx.name_) return QMX_send_char(c);
+
 	start_at2 = monotonic_seconds();
 
 	std::string code = "";
@@ -178,13 +201,14 @@ void send_cwkey(char c)
 	if (xcvr_corr < -tc / 2) xcvr_corr = - tc / 2;
 	else if (xcvr_corr > tc / 2) xcvr_corr = tc / 2;
 
-	if (c == ' ' || c == 0x0a) {
+	code = morse->tx_lookup(c);
+
+	if (code.empty()) {// == ' ' || c == 0x0a) {
 		requested += twd;
 		cw_sleep(twd);
 		goto exit_send_cwkey;
 	}
 
-	code = morse->tx_lookup(c);
 	for (size_t n = 0; n < code.length(); n++) {
 		if (cwio_process == END) {
 			goto exit_send_cwkey;
@@ -278,50 +302,64 @@ static std::string snd;
 
 void update_txt_to_send(void *)
 {
-	txt_to_send->value(snd.c_str());
+	txt_to_send->clear();
+	txt_to_send->buffer()->text(snd.c_str());
 	txt_to_send->redraw();
 }
 
+void update_sent_text(void *loc)
+{
+	char ch[2];
+	ch[1] = 0;
+	ch[0] = *(char *)loc;
+	if (ch[0] == ']') ch[0] = '\n';
+	cw_sent_text->insert( ch );
+	cw_sent_text->redraw();
+}
+
 void terminate_sending(void *)
 {
+	if (progStatus.cwioPTT)
+		doPTT(0);
 	btn_cwioSEND->value(0);
 }
 
 void sending_text()
 {
-	char c = 0;
+	static char c = 0;
 	if (progStatus.cwioPTT) {
 		doPTT(1);
 		MilliSleep(50);
 	}
 	while (cwio_process == SEND) {
 		c = 0;
+		snd = txt_to_send->buffer()->text();
 		{
 			guard_lock lck(&cwio_text_mutex);
-			if (!cwio_text.empty()) {
-				c = cwio_text[0];
-				cwio_text.erase(0,1);
-			}
-		}
-		if (!c) {
-			snd = txt_to_send->value();
 			if (!snd.empty()) {
 				c = snd[0];
 				snd.erase(0,1);
 				Fl::awake(update_txt_to_send);
+				Fl::awake(update_sent_text, &c);
+			} else {
+				if (!cwio_text.empty()) {
+					c = cwio_text[0];
+					cwio_text.erase(0,1);
+				}
 			}
 		}
-		if (c == ']') {
+		if (c == ' ' || c == '\n')
+			send_cwkey(' ');
+		else if (!(morse->tx_lookup(c)).empty())
+			send_cwkey(c);
+		else if (c == ']') {
 			cwio_process = END;
+			snd.clear();
+			Fl::awake(update_txt_to_send);
 			Fl::awake(terminate_sending);
-			return;
-		}
-		if (c) send_cwkey(c);
-		else MilliSleep(50);
-	}
-	if (progStatus.cwioPTT) {
-		doPTT(0);
-		MilliSleep(50);
+			MilliSleep(10);
+		} else
+			MilliSleep(50);
 	}
 }
 
@@ -345,7 +383,7 @@ void do_calibration()
 	for (int i = 0; i < progStatus.cwioWPM; i++)
 		teststr.append(paris);
 
-	txt_to_send->value();
+	txt_to_send->buffer()->text();
 
 	start_time = monotonic_seconds();
 	for (size_t n = 0; n < teststr.length(); n++) {
@@ -371,7 +409,7 @@ void *cwio_loop(void *)
 	cwio_thread_running = true;
 	cwio_process = NONE;
 
-#if 1
+#if 0
 if (PRIORITY) {
 	char estr[200];
 	std::string erfname = RigHomeDir;
@@ -463,26 +501,12 @@ int start_cwio_thread()
 	if(cwio_thread_running) return 0;
 
 	if (!morse)
-		morse = new Cmorse;
+		morse = new cMorse;
 
 	memset((void *) &cwio_pthread, 0, sizeof(cwio_pthread));
 	memset((void *) &cwio_mutex,   0, sizeof(cwio_mutex));
 	memset((void *) &cwio_cond,    0, sizeof(cwio_cond));
 
-#ifdef CWIO_DEBUG
-	if (!fcwio) {
-		std::string debug_fname;
-		debug_fname.assign(RigHomeDir).append("cwio_timing.txt");
-		fcwio = fopen(debug_fname.c_str(), "a");
-	}
-
-	if (!fcwio2) {
-		std::string debug_fname2;
-		debug_fname2.assign(RigHomeDir).append("cwio_bits.txt");
-		fcwio2 = fopen(debug_fname2.c_str(), "a");
-	}
-#endif
-
 	if(pthread_cond_init(&cwio_cond, NULL)) {
 		LOG_ERROR("cwio thread create fail (pthread_cond_init)");
 		return 1;
@@ -493,42 +517,6 @@ int start_cwio_thread()
 		return 1;
 	}
 
-#if 0
-	// bump up the cwio thread priority
-	pthread_attr_t tattr;
-	if (pthread_attr_init(&tattr)) {
-		LOG_ERROR("cwio thread fail (pthread_attr_init)");
-		std::cout << __LINE__ << " : " << errno << ", " << strerror(errno) << std::endl;
-	}
-	sched_param param;
-	int sched;
-	if (pthread_attr_getinheritsched(&tattr, &sched)) {
-		LOG_ERROR("cwio thread fail (pthread_attr_getinheritsched)");
-		std::cout << __LINE__ << " : errno " << errno << ", " << strerror(errno) << std::endl;
-	}
-	sched = PTHREAD_EXPLICIT_SCHED;
-	if (pthread_attr_setinheritsched(&tattr, sched)) {
-		LOG_ERROR("cwio thread fail (pthread_attr_setinheritsched)");
-		std::cout << __LINE__ << " : errno " << errno << ", " << strerror(errno) << std::endl;
-	}
-	if (pthread_attr_getschedparam(&tattr, &param)) {
-		LOG_ERROR("cwio thread fail (pthread_attr_getscheduparam)");
-		std::cout << __LINE__ << " : errno " << errno << ", " << strerror(errno) << std::endl;
-	}
-		std::cout << __LINE__ << " : priority old = " << param.sched_priority << std::endl;
-	param.sched_priority = sched_get_priority_max(SCHED_FIFO);
-		std::cout << __LINE__ << " : priority new = " << param.sched_priority << std::endl;
-	if (pthread_attr_setschedparam(&tattr, &param)) {
-		LOG_ERROR("cwio thread fail (pthread_attr_setscheduparam)");
-		std::cout << __LINE__ << " : errno " << errno << ", " << strerror(errno) << std::endl;
-	}
-	if (pthread_attr_getschedparam(&tattr, &param)) {
-		LOG_ERROR("cwio thread fail (pthread_attr_getscheduparam)");
-		std::cout << __LINE__ << " : errno " << errno << ", " << strerror(errno) << std::endl;
-	}
-	std::cout << __LINE__ << " : priority got = " << param.sched_priority << std::endl;
-#endif
-
 	if (pthread_create(&cwio_pthread, NULL, cwio_loop, NULL) < 0) {
 		pthread_mutex_destroy(&cwio_mutex);
 		LOG_ERROR("cwio thread create fail (pthread_create)");
@@ -590,7 +578,7 @@ void stop_cwio_thread()
 
 }
 
-void add_cwio(std::string txt)
+void add_cwio_msg(std::string txt)
 {
 	if (!cwio_thread_running) return;
 
@@ -637,22 +625,35 @@ void add_cwio(std::string txt)
 				cw_log_nbr->value(progStatus.cw_log_nbr);
 		}
 	}
-	new_text = txt_to_send->value();
+	add_cwio(txt);
+}
+
+void add_cwio(std::string txt)
+{
+	guard_lock lck(&cwio_text_mutex);
+	new_text = txt_to_send->buffer()->text();
 	new_text.append(txt);
 
-	txt_to_send->value(new_text.c_str());
-	txt_to_send->redraw();
-	if (txt[0] == '[') {
-		send_text(true);
+	size_t pos = std::string::npos;
+	if ((pos = new_text.find('[')) != std::string::npos) {
+		while (pos != std::string::npos) {
+			new_text.erase(pos,1);
+			pos = new_text.find('[');
+		}
 		btn_cwioSEND->value(1);
+		send_text(true);
 	}
+	if (new_text.empty()) return;
+	txt_to_send->buffer()->text(new_text.c_str());
+	txt_to_send->redraw();
+	if (new_text[0] == ']') send_text(true);
 }
 
 void send_text(bool state)
 {
 	if (!cwio_thread_running) return;
 
-	if (state && cwio_process != SEND) {
+	if (state) { //&& cwio_process != SEND) {
 		cwio_process = SEND;
 		pthread_cond_signal(&cwio_cond);
 	} else {
@@ -668,7 +669,14 @@ void cwio_new_text(std::string txt)
 
 void cwio_clear_text()
 {
-	txt_to_send->value("");
+	txt_to_send->clear();
+	txt_to_send->redraw();
+}
+
+void cwio_clear_sent_text()
+{
+	cw_sent_text->clear();
+	cw_sent_text->redraw();
 }
 
 void msg_cb(int n)
@@ -689,7 +697,7 @@ void exec_msg(int n)
 		cwio_editor->show();
 		return;
 	}
-	add_cwio(progStatus.cwio_msgs[n]);
+	add_cwio_msg(progStatus.cwio_msgs[n]);
 }
 
 void cancel_edit()
@@ -735,7 +743,7 @@ void control_function_keys()
 			return;
 		}
 		if (key == 'c') {
-			txt_to_send->value("");
+			txt_to_send->clear();
 			return;
 		}
 	}
@@ -746,7 +754,7 @@ void control_function_keys()
 
 void calibrate_cwio()
 {
-	txt_to_send->value("");
+	txt_to_send->clear();
 	btn_cwioSEND->value(0);
 
 	cwio_process = END;
@@ -774,3 +782,260 @@ void open_cwio_config()
 	}
 	cwio_configure->show();
 }
+
+// Send using QMX Kenwood emulation of the QMX_ cat command
+
+int QMX_wpm = 0;
+bool use_QMX_keyer = false;
+
+static cMorse *QMX_morse = 0;
+static char lastQMX_char = 0;
+
+void set_QMX_keyer();
+void QMX_sleep(double secs);
+double QMX_now();
+
+double QMX_now()
+{
+	static struct timespec tp;
+
+#if HAVE_CLOCK_GETTIME
+	clock_gettime(CLOCK_MONOTONIC, &tp); 
+#elif defined(__WIN32__)
+	DWORD msec = GetTickCount();
+	tp.tv_sec = msec / 1000;
+	tp.tv_nsec = (msec % 1000) * 1000000;
+#elif defined(__APPLE__)
+	static mach_timebase_info_data_t info = { 0, 0 };
+	if (unlikely(info.denom == 0))
+		mach_timebase_info(&info);
+	uint64_t t = mach_absolute_time() * info.numer / info.denom;
+	tp.tv_sec = t / 1000000000;
+	tp.tv_nsec = t % 1000000000;
+#endif
+
+	return 1.0 * tp.tv_sec + tp.tv_nsec * 1e-9;
+}
+
+void QMX_sleep(double secs)
+{
+	static struct timespec tv = { 0, 1000000L};
+	static double end1 = 0;
+	static double end2 = 0;
+	static double t1 = 0;
+	static double t2 = 0;
+	static double t3 = 0;
+	int loop1 = 0;
+	int loop2 = 0;
+	int n1 = secs*1e3;
+#ifdef __WIN32__
+	timeBeginPeriod(1);
+#endif
+	t1 = QMX_now();
+	end2 = t1 + secs - 0.0001;
+	end1 = end2 - 0.005;
+
+	t2 = QMX_now();
+	while (t2 < end1 && (++loop1 < n1)) {
+		nano_sleep(&tv, NULL);
+		t2 = QMX_now();
+	}
+	t3 = t2;
+	while (t3 <= end2) {
+		loop2++;
+		t3 = QMX_now();
+	}
+
+#ifdef __WIN32__
+	timeEndPeriod(1);
+#endif
+
+}
+
+void set_QMX_keyer()
+{
+	char cmd[10];
+	snprintf(cmd, sizeof(cmd), "KS%03d;", progStatus.cwioWPM);
+	{
+		guard_lock serial(&mutex_serial, "cwio_set");
+		sendCommand(cmd);
+	}
+	QMX_sleep(0.050);
+	QMX_wpm = progStatus.cwioWPM;
+}
+
+void QMX_send_char(int c)
+{
+	if (QMX_morse == 0) QMX_morse = new cMorse;
+
+	if (QMX_wpm != progStatus.cwioWPM)
+		set_QMX_keyer();
+
+	float tc = 1.2 / progStatus.cwioWPM;
+
+	c = toupper(c);
+	if (c < ' ' || c > 'Z') c = ' ';
+
+	int len = 4;
+	if (lastQMX_char == ' ') len = 7;
+	if (c != ' ')
+		len = QMX_morse->tx_length(c);
+
+	char cmd[10];
+	snprintf(cmd, sizeof(cmd), "KY %c;", c);
+	{
+		guard_lock serial(&mutex_serial, "cwio_send");
+		sendCommand(cmd);
+	}
+	QMX_sleep(tc * len);
+
+	lastQMX_char = c;
+
+}
+
+//----------------------------------------------------------------------
+// CW output on GPIO pin
+//----------------------------------------------------------------------
+
+#if USE_LIBGPIOD
+
+#include <queue>
+#include <fcntl.h>
+
+#include "gpio_common.h"
+
+static gpio_num_t		cw_gpio_num = GPIO_COMMON_UNKNOWN;
+
+//----------------------------------------------------------------------
+static void set_gpio_pin(bool key)
+{
+	int ret;
+
+	ret = gpio_common_set(cw_gpio_num, key);
+
+	if (ret < 0) {
+		LOG_ERROR("Error setting GPIO");
+	}
+
+}
+
+//----------------------------------------------------------------------
+
+static double CW_gpio_now()
+{
+	static struct timespec tp;
+
+#if HAVE_CLOCK_GETTIME
+	clock_gettime(CLOCK_MONOTONIC, &tp); 
+#elif defined(__WIN32__)
+	DWORD msec = GetTickCount();
+	return 1.0 * msec;
+	tp.tv_sec = msec / 1000;
+	tp.tv_nsec = (msec % 1000) * 1000000;
+#elif defined(__APPLE__)
+	static mach_timebase_info_data_t info = { 0, 0 };
+	if (unlikely(info.denom == 0))
+		mach_timebase_info(&info);
+	uint64_t t = mach_absolute_time() * info.numer / info.denom;
+	tp.tv_sec = t / 1000000000;
+	tp.tv_nsec = t % 1000000000;
+#endif
+	return 1.0 * tp.tv_sec + tp.tv_nsec * 1e-9;
+
+}
+
+static void CW_gpio_bit(int bit, double msecs)
+{
+	static double secs;
+	static struct timespec tv = { 0, 1000000L};
+	static double end1 = 0;
+	static double end2 = 0;
+	static double t1 = 0;
+#ifdef CW_gpio_TTEST
+	static double t2 = 0;
+#endif
+	static double t3 = 0;
+	static double t4 = 0;
+	int loop1 = 0;
+	int loop2 = 0;
+	int n1 = msecs * 1e3;
+
+	secs = msecs * 1e-3;
+
+#ifdef __WIN32__
+	timeBeginPeriod(1);
+#endif
+
+	t1 = CW_gpio_now();
+
+	end2 = t1 + secs - 0.00001;
+
+	set_gpio_pin(bit);
+
+#ifdef CW_gpio_TTEST
+	t2 = t3 = CW_gpio_now();
+#else
+	t3 = CW_gpio_now();
+#endif
+	end1 = end2 - 0.005;
+
+	while (t3 < end1 && (++loop1 < n1)) {
+		nano_sleep(&tv, NULL);
+		t3 = CW_gpio_now();
+	}
+
+	t4 = t3;
+	while (t4 <= end2) {
+		loop2++;
+		t4 = CW_gpio_now();
+	}
+
+#ifdef __WIN32__
+	timeEndPeriod(1);
+#endif
+
+}
+
+void send_gpio_CW(int c)
+{
+	if (!morse) {
+		morse = new cMorse;
+		morse->init();
+	}
+
+	if (c == 0x0d) {
+		return;
+	}
+
+	float tc = 1200.0 / progStatus.cwioWPM;
+	if (tc <= 0) tc = 1;
+
+	if (c == 0x0a) c = ' ';
+
+	if (c == ' ') {
+		CW_gpio_bit(0, 4 * tc);
+		return;
+	}
+
+	std::string code = morse->tx_lookup(c);
+	if (code.empty()) {
+		return;
+	}
+
+	double weight = progStatus.cw_weight;
+
+	for (size_t n = 0; n < code.length(); n++) {
+		if (code[n] == '.') {
+			CW_gpio_bit(1, tc * (1 + weight));
+		} else {
+			CW_gpio_bit(1, 3*tc * (1 + weight));
+		}
+		if (n < code.length() -1) {
+			CW_gpio_bit(0, tc * (1 - weight));
+		} else {
+			CW_gpio_bit(0, 3 * tc - tc * weight);
+		}
+	}
+}
+
+#endif // USE_LIBGPIOD
