@@ -69,7 +69,7 @@ public:
 	int  get_pbt_inner();
 	int  get_pbt_outer();
 
-	const char *FILT(int &val);
+	const char *FILT(int val);
 	const char *nextFILT();
 
 	void set_compression(int, int);
