@@ -31,6 +31,8 @@
 #define MAX_DEFBUFFER_SIZE 500
 
 struct status {
+	int		screen_number;
+	int		screen_scale;
 	int		mainX;
 	int		mainY;
 	int		mainW;
@@ -43,6 +45,32 @@ struct status {
 	int		memW;
 	int		memH;
 
+	int		cwioUI_X;
+	int		cwioUI_Y;
+	int		cwioUI_W;
+	int		cwioUI_H;
+	int		cw_sent_bkgnd_color;
+	int		cw_sent_text_font;
+	int 	cw_sent_text_size;
+	int		cw_sent_font_color;
+	int		txt_to_send_bkgnd_color;
+	int		txt_to_send_font;
+	int 	txt_to_send_size;
+	int		txt_to_send_font_color;
+
+	int		fskUI_X;
+	int		fskUI_Y;
+	int		fskUI_W;
+	int		fskUI_H;
+	int		fsk_sent_bkgnd_color;
+	int		fsk_sent_text_font;
+	int 	fsk_sent_text_size;
+	int		fsk_sent_font_color;
+	int		fsk_txt_to_send_bkgnd_color;
+	int		fsk_txt_to_send_font;
+	int 	fsk_txt_to_send_size;
+	int		fsk_txt_to_send_font_color;
+
     int     metersX;
     int     metersY;
     bool	meters_dialog_visible;
@@ -500,6 +528,15 @@ struct status {
 	int		gpio_on;
 	int		gpio_pulse_width;
 
+// gpio deamon
+	std::string		gpio_ptt_device;
+	int		gpio_ptt_line;
+	int		enable_gpio_ptt;
+
+	std::string		gpio_cw_device;
+	int		gpio_cw_line;
+	int		enable_gpio_cw;
+
 // KXPA 100 presence
 //	int		kxpa;
 
