@@ -154,9 +154,6 @@ public:
 	int  get_attenuator();
 	int  next_attenuator();
 
-	const char * PRE_label();
-	const char * ATT_label();
-
 	void set_noise(bool val);
 	int  get_noise();
 	void set_nb_level(int val);
