@@ -159,9 +159,15 @@ Version %s\n\
 copyright W1HKJ  <w1hkj25@@gmail.com>\n\
 Developer:  Dave,  W1HKJ\n\
 \n\
+Built with Fltk library version %s\n\
+\n\
 Dedicated to the memory of Mike Black, W9MDB,\n\
 hamlib expert, and prolific contributor to flrig.";
-	fl_message(msg.c_str(), PACKAGE_TARNAME, PACKAGE_VERSION);
+	fl_message(
+		msg.c_str(), 
+		PACKAGE_TARNAME, 
+		PACKAGE_VERSION,
+		FLTK_BUILD_VERSION );
 }
 
 void visit_URL(void* arg)
