@@ -109,6 +109,14 @@ static const char *vIC9700_fixed_bws[] =
 { "FIXED" };
 static int IC9700_bw_vals_fixed[] = { 1, WVALS_LIMIT};
 
+//----------------------------------------------------------------------
+static std::vector<std::string>IC9700_att_labels;
+static const char *vIC9700_att_labels[] = { "ATT", "10 dB" };
+
+static std::vector<std::string>IC9700_pre_labels;
+static const char *vIC9700_pre_labels[] = { "P0/E0", "P1/E0", "P0/E1", "P1/E1" };
+//----------------------------------------------------------------------
+
 static GUI IC9700_widgets[]= {
 	{ (Fl_Widget *)btnVol,        2, 125,  50 },	//0
 	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },	//1
@@ -143,6 +151,12 @@ void RIG_IC9700::initialize()
 
 	_mode_type = IC9700_mode_type;
 
+	VECTOR (IC9700_att_labels, vIC9700_att_labels);
+	VECTOR (IC9700_pre_labels, vIC9700_pre_labels);
+
+	att_labels_ = IC9700_att_labels;
+	pre_labels_ = IC9700_pre_labels;
+
 	IC9700_widgets[0].W = btnVol;
 	IC9700_widgets[1].W = sldrVOLUME;
 	IC9700_widgets[2].W = btnAGC;
@@ -272,6 +286,8 @@ RIG_IC9700::RIG_IC9700() {
 	can_change_alt_vfo = true;
 	has_a2b = true;
 
+	can_synch_clock = true;
+
 	precision = 1;
 	ndigits = 10;
 
@@ -1389,13 +1405,16 @@ void RIG_IC9700::get_notch_min_max_step(int &min, int &max, int &step)
 
 void RIG_IC9700::set_auto_notch(int val)
 {
+	progStatus.auto_notch = an_level = val;
 	cmd = pre_to;
 	cmd += '\x16';
 	cmd += '\x41';
-	cmd += val ? 0x01 : 0x00;
+	cmd += (unsigned char)val;
 	cmd.append( post );
+	set_trace(1, "set auto notch");
 	waitFB("set AN");
-	set_trace(2, "set_auto_notch()", str2hex(replystr.c_str(), replystr.length()));
+	seth();
+	auto_notch_label(an_label(), an_level ? true : false);
 }
 
 int RIG_IC9700::get_auto_notch()
@@ -1406,17 +1425,16 @@ int RIG_IC9700::get_auto_notch()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(8, "get AN")) {
-		get_trace(2, "get_auto_notch()", str2hex(replystr.c_str(), replystr.length()));
+
+	get_trace(1, "get_auto_notch()");
+	ret = waitFOR(8, "get AN");
+	geth();
+
+	if (ret) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			if (replystr[p+6] == 0x01) {
-				auto_notch_label("AN", true);
-				return true;
-			} else {
-				auto_notch_label("AN", false);
-				return false;
-			}
+			progStatus.auto_notch = an_level = replystr[p+6];
+			auto_notch_label(an_label(), an_level ? true : false);
 		}
 	}
 	return progStatus.auto_notch;
@@ -1438,7 +1456,6 @@ int  RIG_IC9700::get_split()
 	return split;
 }
 
-static int agcval = 1;
 int  RIG_IC9700::get_agc()
 {
 	cmd = pre_to;
@@ -1481,14 +1498,14 @@ int  RIG_IC9700::agc_val()
 void RIG_IC9700::set_attenuator(int val)
 {
 	if (val) {
-		atten_level = 1;
+		atten_state = 1;
 	} else {
-		atten_level = 0;
+		atten_state = 0;
 	}
 
 	cmd = pre_to;
 	cmd += '\x11';
-	cmd += atten_level ? '\x10' : '\x00';
+	cmd += atten_state ? '\x10' : '\x00';
 	cmd.append( post );
 	waitFB("set att");
 	std::stringstream ss;
@@ -1499,7 +1516,7 @@ void RIG_IC9700::set_attenuator(int val)
 
 int RIG_IC9700::next_attenuator()
 {
-	if (atten_level) return 0;
+	if (atten_state) return 0;
 	return 1;
 }
 
@@ -1514,10 +1531,10 @@ int RIG_IC9700::get_attenuator()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			if (!replystr[p+5]) {
-				atten_level = 0;
+				atten_state = 0;
 				return 0;
 			} else {
-				atten_level = 1;
+				atten_state = 1;
 				return 1;
 			}
 		}
@@ -1528,7 +1545,7 @@ int RIG_IC9700::get_attenuator()
 
 int RIG_IC9700::next_preamp()
 {
-	switch (preamp_level) {
+	switch (preamp_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 3;
@@ -1540,12 +1557,12 @@ int RIG_IC9700::next_preamp()
 
 void RIG_IC9700::set_preamp(int val)
 {
-	preamp_level = val;
+	preamp_state = val;
 
 	cmd = pre_to;
 	cmd += '\x16';
 	cmd += '\x02';
-	cmd += preamp_level;
+	cmd += preamp_state;
 	cmd.append( post );
 	waitFB("set Pre");
 
@@ -1566,36 +1583,11 @@ int RIG_IC9700::get_preamp()
 	if (waitFOR(8, "get Pre")) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos)
-			preamp_level = replystr[p+6];
+			preamp_state = replystr[p+6];
 	}
 	get_trace(2, "get_preamp()", str2hex(replystr.c_str(), replystr.length()));
 
-	return preamp_level;
-}
-
-const char *RIG_IC9700::PRE_label()
-{
-	switch (preamp_level) {
-		case 0 : default:
-			break;
-		case 1 :
-			return("P1/E0");
-			break;
-		case 2 :
-			return("P0/E1");
-			break;
-		case 3 :
-			return("P1/E1");
-			break;
-	}
-	return("P0/E0");
-}
-
-const char *RIG_IC9700::ATT_label()
-{
-	if (atten_level == 1)
-		return("10 dB");
-	return "ATT";
+	return preamp_state;
 }
 
 // Tranceiver PTT on/off
@@ -2055,5 +2047,53 @@ int RIG_IC9700::get_dualwatch()
 	return iret;
 }
 
+// ---------------------------------------------------------------------
+// set date and time
+// 1A 05 00 95 HH MM : set time
+// 1A 05 00 94 YY YY MM DD : set date
+// ---------------------------------------------------------------------
+// dt formated as YYYYMMDD
+// ---------------------------------------------------------------------
+void RIG_IC9700::sync_date(char *dt)
+{
+	cmd.clear();
+	cmd.append(pre_to);
+	cmd += '\x1A'; cmd += '\x05';
+	cmd += '\x00'; cmd += '\x79';
+	unsigned char val;
+	val = ((dt[0] - '0') << 4) + (dt[1] - '0');
+	cmd += (val & 0xFF);
+	val = ((dt[2] - '0') << 4) + (dt[3] - '0');
+	cmd += (val & 0xFF);
+	val = ((dt[4] - '0') << 4) + (dt[5] - '0');
+	cmd += (val & 0xFF);
+	val = ((dt[6] - '0') << 4) + (dt[7] - '0');
+	cmd += (val & 0xFF);
+	cmd.append(post);
+	set_trace(1, "set xcvr clock");
+	waitFB("set xcvr clock", 200);
+	seth();
+}
+
+// ---------------------------------------------------------------------
+// tm formated as HH:MM:SS
+// ---------------------------------------------------------------------
+void RIG_IC9700::sync_clock(char *tm)
+{
+	cmd.clear();
+	cmd.append(pre_to);
+	cmd += '\x1A'; cmd += '\x05';
+	cmd += '\x00'; cmd += '\x80';
+	unsigned char val;
+	val = ((tm[0] - '0') << 4) + (tm[1] - '0');
+	cmd += (val & 0xFF);
+	val = ((tm[3] - '0') << 4) + (tm[4] - '0');
+	cmd += (val & 0xFF);
+	cmd.append(post);
+	set_trace(1, "set xcvr clock");
+	waitFB("set xcvr clock", 200);
+	seth();
+}
+
 
 
