@@ -107,7 +107,7 @@ void RIG_ICOM::ICtrace(std::string cmd, std::string hexstr)
 	rig_trace(2, cmd.c_str(), s1.c_str());
 }
 
-bool RIG_ICOM::waitFOR(size_t n, const char *sz, unsigned long timeout)
+bool RIG_ICOM::waitFOR(size_t n, const char *sz, ullint timeout)
 {
 	static char sztemp[200];
 	memset(sztemp, 0, 200);
@@ -132,63 +132,66 @@ bool RIG_ICOM::waitFOR(size_t n, const char *sz, unsigned long timeout)
 		return replystr.length();
 	}
 
-	size_t tstart = 0;
-	size_t tout = 0;
+	ullint tstart = 0;
+	ullint tout = 0;
 	size_t pcheck = 0;
 	size_t peor = 0;
 
-	if (progStatus.use_tcpip) {
+	if(!progStatus.use_tcpip && !RigSerial->IsOpen()) {
+		LOG_DEBUG("TEST %s", sz);
+		return false;
+	}
+	   if (progStatus.use_tcpip) {
 		send_to_remote(cmd);
-		MilliSleep(progStatus.tcpip_ping_delay);
-		retnbr = read_from_remote(replystr);
-		LOG_DEBUG ("%s: read %d bytes, %s", sz, retnbr, replystr.c_str());
-	} else {
-		if(!RigSerial->IsOpen()) {
-			LOG_DEBUG("TEST %s", sz);
-			return false;
+	   }
+	   else {
+   		RigSerial->FlushBuffer();
+	  	RigSerial->WriteBuffer(cmd.c_str(), cmd.length());
+	   }
+
+	tstart = zmsec();
+	tout = tstart + timeout;
+	pcheck = std::string::npos;
+	peor = std::string::npos;
+
+	std::string tempstr;
+	int nret = 0;
+
+	while ( zmsec() < tout ) {
+		tempstr.clear();
+		if (progStatus.use_tcpip) {
+			read_from_remote(tempstr);
 		}
-		RigSerial->FlushBuffer();
-		RigSerial->WriteBuffer(cmd.c_str(), cmd.length());
-
-		tstart = zmsec();
-		tout = tstart + timeout;
-		pcheck = std::string::npos;
-		peor = std::string::npos;
-
-		std::string tempstr;
-		int nret;
-
-		while ( zmsec() < tout ) {
-			tempstr.clear();
+		else {
 			nret = RigSerial->ReadBuffer(
 				tempstr, 
 				n,
 				check, 
 				eor);
-			replystr.append(tempstr);
-			retnbr += nret;
-
-			if (replystr.rfind(bad) != std::string::npos) {
-				LOG_ERROR("%s: BAD response; %s", sz, str2hex(replystr.c_str(), replystr.length()));
-				return false;
-			}
-			pcheck = replystr.rfind(check);
-			peor = replystr.rfind(eor);
-
-			if ((pcheck != std::string::npos) && 
-				(peor != std::string::npos) &&
-				(peor > pcheck) ) {
-				LOG_DEBUG("%s: read %d bytes in %d msec, %s", 
-						sz,
-						retnbr,
-						(int)(zmsec() - tstart), 
-						str2hex(replystr.c_str(), replystr.length()));
-				return true;
-			}
-			MilliSleep(1);
 		}
+		replystr.append(tempstr);
+		retnbr += nret;
 
+		if (replystr.rfind(bad) != std::string::npos) {
+			LOG_ERROR("%s: BAD response; %s", sz, str2hex(replystr.c_str(), replystr.length()));
+			return false;
+		}
+		pcheck = replystr.rfind(check);
+		peor = replystr.rfind(eor);
+
+		if ((pcheck != std::string::npos) && 
+			(peor != std::string::npos) &&
+			(peor > pcheck) ) {
+			LOG_DEBUG("%s: read %d bytes in %d msec, %s", 
+					sz,
+					retnbr,
+					(int)(zmsec() - tstart), 
+					str2hex(replystr.c_str(), replystr.length()));
+			return true;
+		}
+		MilliSleep(1);
 	}
+
 	LOG_ERROR("%s: FAILED in %d msec; %s", 
 			sz,
 			(int)(zmsec() - tstart),
@@ -199,7 +202,7 @@ bool RIG_ICOM::waitFOR(size_t n, const char *sz, unsigned long timeout)
 // waitFB - This function sends the command in the 'cmd' member string (via 'waitFOR'),
 //          specifying the number of bytes in the expected resposne.  'waitFOR' already
 //          knows the construction of the response message so this seems superfluous.
-bool RIG_ICOM::waitFB(const char *sz, unsigned long timeout)
+bool RIG_ICOM::waitFB(const char *sz, ullint timeout)
 {
 #if SERIAL_DEBUG
 fprintf(serlog, "waitFB\n");
