@@ -67,6 +67,14 @@ static std::vector<std::string>Xiegu_G90_ssb_bws;
 static const char *vXiegu_G90_ssb_bws[] = { "N/A" };
 static int Xiegu_G90_vals_ssb_bws[] = { 1, WVALS_LIMIT };
 
+//----------------------------------------------------------------------
+static std::vector<std::string>Xiegu_G90_att_labels;
+static const char *vXiegu_G90_att_labels[] = { "ATT", "Att ON" };
+
+static std::vector<std::string>Xiegu_G90_pre_labels;
+static const char *vXiegu_G90_pre_labels[] = { "PRE", "Pre ON" };
+//----------------------------------------------------------------------
+
 struct bpair {Fl_Widget *widget; std::string lbl;};
 static bpair bpcomp;
 
@@ -102,6 +110,12 @@ void RIG_Xiegu_G90::initialize()
 	VECTOR (Xiegu_G90modes_, vXiegu_G90modes_);
 	VECTOR (Xiegu_G90_ssb_bws, vXiegu_G90_ssb_bws);
 
+	VECTOR (Xiegu_G90_att_labels, vXiegu_G90_att_labels);
+	att_labels_ = Xiegu_G90_att_labels;
+
+	VECTOR (Xiegu_G90_pre_labels, vXiegu_G90_pre_labels);
+	pre_labels_ = Xiegu_G90_pre_labels;
+
 	modes_ = Xiegu_G90modes_;
 	bandwidths_ = Xiegu_G90_ssb_bws;
 	bw_vals_ = Xiegu_G90_vals_ssb_bws;
@@ -134,15 +148,16 @@ RIG_Xiegu_G90::RIG_Xiegu_G90() {
 	_mode_type = Xiegu_G90_mode_type;
 	adjustCIV(defaultCIV);
 
+	serial_baudrate = BR19200;
+	stopbits = 1;
 	serial_retries = 2;
+	serial_write_delay = 0;
+	serial_post_write_delay = 50;
+	serial_timeout = 100;
 
-//	serial_write_delay = 0;
-//	serial_post_write_delay = 0;
-
-	serial_timeout = 50;
-	serial_echo = false;
+	serial_echo = true;
 	serial_rtscts = false;
-	serial_rtsplus = true;
+	serial_rtsplus = false;
 	serial_dtrplus = true;
 	serial_catptt = true;
 	serial_rtsptt = false;
@@ -174,7 +189,7 @@ RIG_Xiegu_G90::RIG_Xiegu_G90() {
 	has_volume_control = 
 	has_sql_control = 
 	has_noise_control = 
-	has_attenuator_control = 
+//	has_attenuator_control = 
 	has_preamp_control = 
 	has_ptt_control = 
 	has_agc_control = 
@@ -488,17 +503,18 @@ int RIG_Xiegu_G90::get_modeB()
 	return B.imode;
 }
 
+/*
 void RIG_Xiegu_G90::set_attenuator(int val)
 {
    if (val) {
-		atten_level = 1;
+		atten_state = 1;
 	} else {
-		atten_level = 0;
+		atten_state = 0;
 	}
 
 	cmd = pre_to;
 	cmd += '\x11';
-	cmd += atten_level ? '\x01' : '\x00';
+	cmd += atten_state ? '\x01' : '\x00';
 	cmd.append( post );
 	set_trace(1, "set_attenuator()");
 	waitFB("set att");
@@ -517,13 +533,14 @@ int RIG_Xiegu_G90::get_attenuator()
 		igett("");
 		size_t p = replystr.rfind(resp);
 		if (replystr[p+5] == 0x00) {
-			atten_level = 0;
+			atten_state = 0;
 		} else {
-			atten_level = 1;
+			atten_state = 1;
 		}
 	}
-	return atten_level;
+	return atten_state;
 }
+*/
 
 void RIG_Xiegu_G90::set_preamp(int val)
 {
@@ -557,27 +574,9 @@ int RIG_Xiegu_G90::get_preamp()
 		igett("");
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos)
-			preamp_level = replystr[p+6];
+			preamp_state = replystr[p+6];
 	}
-	return preamp_level;
-}
-
-const char *RIG_Xiegu_G90::PRE_label()
-{
-	switch (preamp_level) {
-		case 0: default:
-			return "PRE"; break;
-		case 1:
-			return "ON"; break;
-	}
-	return "PRE";
-}
-
-const char *RIG_Xiegu_G90::ATT_label()
-{
-	if (atten_level)
-		return "ON";
-	return "ATT";
+	return preamp_state;
 }
 
 static int compon = 0;
@@ -634,8 +633,6 @@ static char hexchr(int val)
 	return c;
 }
 
-struct meterpair {int mtr; float val;};
-
 static meterpair pwrtbl[] = { 
 { 0, 1 },
 { 13, 2 },
@@ -873,24 +870,17 @@ int RIG_Xiegu_G90::get_smeter()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	int mtr= 0;
-	get_trace(1, "get smeter");
-	if (waitFOR(8, "get smeter")) {
-		igett("");
+	int mtr= -1;
+	if (waitFOR(9, "get smeter")) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			if (replystr[p + 7] == '\xFD') {
-				mtr = hexval(replystr[p + 6]);
-			} else {
-				mtr = 100 * hexval(replystr[p + 6]) + hexval(replystr[p + 7]);
-			}
-			if (mtr < 0) mtr = 0;
-			if (mtr > 241) mtr = 241;
 			size_t i = 0;
-			for (i = 0; i < sizeof(smtrtbl) / sizeof(meterpair) - 1; i++)
+			for (i = 0; i < sizeof(smtrtbl) / sizeof(*smtrtbl) - 1; i++)
 				if (mtr >= smtrtbl[i].mtr && mtr < smtrtbl[i+1].mtr)
 					break;
-			mtr = (int)ceil(smtrtbl[i].val + 
+			if (mtr < 0) mtr = 0;
+			if (mtr > 255) mtr = 255;
+			mtr = (int)ceil(smtrtbl[i].val +
 				(smtrtbl[i+1].val - smtrtbl[i].val)*(mtr - smtrtbl[i].mtr)/(smtrtbl[i+1].mtr - smtrtbl[i].mtr));
 			if (mtr > 100) mtr = 100;
 		}
@@ -918,24 +908,17 @@ int RIG_Xiegu_G90::get_swr()
 	cmd.append(cstr);
 	cmd.append( post );
 	int mtr= -1;
-	get_trace(1, "get swr");
-	if (waitFOR(9, "get SWR")) 
-	{
-		igett("");
+	if (waitFOR(9, "get swr")) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			if (replystr[p + 7] == '\xFD') {
-				mtr = hexval(replystr[p + 6]);
-			} else {
-				mtr = 100 * hexval(replystr[p + 6]) + hexval(replystr[p + 7]);
-			}
+			mtr = fm_bcd(replystr.substr(p+6), 3);
 			size_t i = 0;
-			for (i = 0; i < sizeof(swrtbl) / sizeof(meterpair) - 1; i++)
+			for (i = 0; i < sizeof(swrtbl) / sizeof(*swrtbl) - 1; i++)
 				if (mtr >= swrtbl[i].mtr && mtr < swrtbl[i+1].mtr)
 					break;
 			if (mtr < 0) mtr = 0;
 			if (mtr > 255) mtr = 255;
-			mtr = (int)ceil(swrtbl[i].val + 
+			mtr = (int)ceil(swrtbl[i].val +
 				(swrtbl[i+1].val - swrtbl[i].val)*(mtr - swrtbl[i].mtr)/(swrtbl[i+1].mtr - swrtbl[i].mtr));
 			if (mtr > 100) mtr = 100;
 		}
@@ -956,20 +939,20 @@ void RIG_Xiegu_G90::set_noise(bool val)
 
 int RIG_Xiegu_G90::get_noise()
 {
+	int val = progStatus.noise;
 	std::string cstr = "\x16\x22";
 	std::string resp = pre_fm;
 	resp.append(cstr);
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append(post);
-	get_trace(1, "get noise");
 	if (waitFOR(8, "get noise")) {
-		igett("");
 		size_t p = replystr.rfind(resp);
-		if (p != std::string::npos)
-			return (replystr[p+6] ? 1 : 0);
+		if (p != std::string::npos) {
+			val = replystr[p+6];
+		}
 	}
-	return progStatus.noise;
+	return val;
 }
 
 void RIG_Xiegu_G90::get_band_selection(int v)
@@ -1024,7 +1007,6 @@ void RIG_Xiegu_G90::set_band_selection(int v)
 	set_trace(1, "set_band_selection()");
 }
 
-static int agcval = 0;
 int  RIG_Xiegu_G90::get_agc()
 {
 	cmd = pre_to;
