@@ -82,6 +82,14 @@ static std::vector<std::string>FT450D_US_60m = {"", "126", "127", "128", "130"};
 static std::vector<std::string>& Channels_60m = FT450D_US_60m;
 */
 
+//----------------------------------------------------------------------
+static std::vector<std::string>FT450D_att_labels;
+static const char *vFT450D_att_labels[] = { "ATT", "12 dB" };
+
+static std::vector<std::string>FT450D_pre_labels;
+static const char *vFT450D_pre_labels[] = { "IPO", "Amp 1" };
+//----------------------------------------------------------------------
+
 static GUI rig_widgets[]= {
 	{ (Fl_Widget *)btnVol,        2, 125,  50 },
 	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },
@@ -193,6 +201,12 @@ void RIG_FT450D::initialize()
 	VECTOR( FT450D_am_widths, vFT450D_am_widths);
 	VECTOR( FT450D_fm_widths, vFT450D_fm_widths);
 
+	VECTOR (FT450D_att_labels, vFT450D_att_labels);
+	att_labels_ = FT450D_att_labels;
+
+	VECTOR (FT450D_pre_labels, vFT450D_pre_labels);
+	pre_labels_ = FT450D_pre_labels;
+
 	modes_ = FT450Dmodes_;
 	bandwidths_ = FT450D_ssb_widths;
 	bw_vals_ = FT450D_wvals_ssb_widths;
@@ -378,17 +392,6 @@ int RIG_FT450D::get_split()
 	return split;
 }
 
-struct mtrpair {int val; float mtr;};
-
-static mtrpair sm_tbl[] = { 
-{0, 0.0},
-{18, 6.0},
-{51, 17.0},
-{85, 28.0},
-{118, 39.0},
-{151, 50.0},
-{255, 100.0} };
-
 int RIG_FT450D::get_smeter()
 {
 	cmd = rsp = "SM0";
@@ -397,21 +400,9 @@ int RIG_FT450D::get_smeter()
 	wait_char(';',7, FL450D_WAIT_TIME, "get smeter", ASC); // sets replystr via rigbase
 	gett("");
 
-	size_t p = replystr.rfind(rsp);
-	if (p == std::string::npos) return 0;
-	if (p + 6 >= replystr.length()) return 0;
-	int val = atoi(&replystr[p+3]);
-	
-	size_t i = 0;
-	if (val < 0) val = 0;
-	else if (val > 255) val = 255;
-	else while(val > sm_tbl[i].val) i++;
-	int mtr = (int)ceil(sm_tbl[i].mtr + 
-				(sm_tbl[i+1].mtr - sm_tbl[i].mtr) * 
-				(val - sm_tbl[i].val)/(sm_tbl[i+1].val - sm_tbl[i].val));
-
-	if (mtr > 100) mtr = 100;
-
+	int mtr = 0;
+	sscanf(replystr.c_str(), "SM0%d", &mtr);
+	mtr = mtr * 100.0 / 256.0;
 	return mtr;
 }
 
@@ -465,9 +456,7 @@ int RIG_FT450D::get_alc()
 //		zone 2: 10 - 50W  --> Slope = 2.2; Intercept = 54
 //		zone 1: 50 - 100W --> Slope = 1.5; Intercept = 91
 
-struct pwrpair {int mtr; double pwr;};
-
-static pwrpair pwrtbl[] = { 
+static meterpair pwrtbl[] = { 
   {0, 0.0},
   {74, 10.0},
   {164, 50.0},
@@ -490,13 +479,13 @@ int RIG_FT450D::get_power_out()
 	if (mtr > 238) mtr = 238;
 
 	size_t i = 0;
-	for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
+	for (i = 0; i < sizeof(pwrtbl) / sizeof(meterpair) - 1; i++)
 		if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
 			break;
 
 	double pwr = floor (
-					pwrtbl[i].pwr + 
-					(pwrtbl[i+1].pwr - pwrtbl[i].pwr) * (mtr - pwrtbl[i].mtr) / (pwrtbl[i+1].mtr - pwrtbl[i].mtr)
+					pwrtbl[i].val + 
+					(pwrtbl[i+1].val - pwrtbl[i].val) * (mtr - pwrtbl[i].mtr) / (pwrtbl[i+1].mtr - pwrtbl[i].mtr)
 				);
 	if (pwr > 100) pwr = 100;
 	return (int)pwr;
@@ -645,10 +634,10 @@ int RIG_FT450D::get_attenuator()
 	gett("get_attenuator");
 
 	size_t p = replystr.rfind(rsp);
-	atten_level = 0;
+	atten_state = 0;
 	if (p != std::string::npos)
-		atten_level = (replystr[p+3] == '3' ? 1 : 0);
-	return atten_level;
+		atten_state = (replystr[p+3] == '3' ? 1 : 0);
+	return atten_state;
 }
 
 static int preval = 0;
@@ -683,20 +672,6 @@ int RIG_FT450D::get_preamp()
 	return preval;
 }
 
-const char *RIG_FT450D::ATT_label()
-{
-	if (atten_level == 1)
-		return "12 dB";
-	return "ATT";
-}
-
-const char *RIG_FT450D::PRE_label()
-{
-	if (preamp_level == 1)
-		return "Amp 1";
-	return "IPO";
-}
-
 int RIG_FT450D::adjust_bandwidth(int val)
 {
 	switch (val) {
@@ -1055,23 +1030,58 @@ void RIG_FT450D::set_noise(bool b)
 
 void RIG_FT450D::set_xcvr_auto_on()
 {
-// send dummy data request for ID (see pg 12 CAT reference book)
 	cmd = "ID;";
-	sendCommand(cmd);
-// wait 1 to 2 seconds
-	MilliSleep(1500);
+	wait_char(';', 7 , 100, "check", ASC);
+	if (replystr.find("ID") != std::string::npos) // xcvr already ON
+		return;
+
+	update_progress(0);
+// wait 1.5 seconds
+	for (int i = 0; i < 10; i++) {
+		MilliSleep(150);
+		update_progress(i * 10);
+		Fl::awake();
+	}
+
 	cmd = "PS1;";
 	sendCommand(cmd);
-// wait for power on status
+	sett("set xcvr auto ON");
+
+	update_progress(0);
+
+// wait up to 10 seconds for normal response
 	cmd = "PS;";
-	waitN(4, 500, "Xcvr ON?", ASC);
+	for (int i = 0; i < 100; i++) {
+		wait_char(';', 4, 100, "Test for xcvr ON", ASC);
+		if (replystr.find("PS1;") != std::string::npos) {
+			update_progress(100);
+			break;
+		}
+		update_progress(i);
+		Fl::awake();
+	}
+	update_progress(0);
+
+	wait_char(';', 4, 100, "Test for xcvr ON", ASC);
+	if (replystr.find("PS1;") == std::string::npos)
+		LOG_ERROR("%s", "Unable to start xcvr");
+
 }
 
 void RIG_FT450D::set_xcvr_auto_off()
 {
 	cmd = "PS0;";
 	sendCommand(cmd);
-	sett("set_xcvr_auto_off");
+	sett("set_xcvr_auto_OFF");
+
+// transceiver does not respond after a power OFF
+
+	for (int i = 0; i < 100; i++) {
+		cmd = "PS;";
+		wait_char(';', 4, 100, "Test for xcvr OFF", ASC);
+		if (replystr.empty()) break;
+		Fl::awake();
+	}
 }
 
 // val 0 .. 100
@@ -1354,31 +1364,31 @@ void RIG_FT450D::get_rf_min_max_step(int &min, int &max, int &step)
 //----------------------------------------------------------------------
 // these are used during initialization
 
-void RIG_FT450D::get_cw_weight()
+int RIG_FT450D::get_cw_weight()
 {
 	cmd = "EX024;";
 	wait_char(';', 9, FL450D_WAIT_TIME, "get CW weight", ASC);
 	gett("get_cw_weight");
 
 	size_t p = replystr.rfind("EX024");
-	if (p == std::string::npos) return;
+	if (p == std::string::npos) return progStatus.cw_weight;
 	replystr[p+8] = 0;
 	int val = atoi(&replystr[p+5]);
-	progStatus.cw_weight = val / 10.0;
+	return (progStatus.cw_weight = val / 10.0);
 }
 
-void RIG_FT450D::get_cw_wpm()
+int RIG_FT450D::get_cw_wpm()
 {
 	cmd = rsp = "KS;";
 	wait_char(';', 6, FL450D_WAIT_TIME, "get WPM", ASC);
 	gett("get_cw_wpm");
 
 	size_t p = replystr.rfind("KS");
-	if (p == std::string::npos) return;
+	if (p == std::string::npos) return progStatus.cw_wpm;
 
 	replystr[p+5] = 0;
 	int val = atoi(&replystr[p+2]);
-	progStatus.cw_wpm = val;
+	return (progStatus.cw_wpm = val);
 }
 
 void RIG_FT450D::get_qsk()
@@ -1411,14 +1421,14 @@ void RIG_FT450D::get_qsk_delay()
 	progStatus.cw_delay = atoi(&replystr[p+5]);
 }
 
-void RIG_FT450D::get_cw_spot_tone()
+int RIG_FT450D::get_cw_spot_tone()
 {
 	cmd = "EX020;";
 	wait_char(';', 8, FL450D_WAIT_TIME, "get CW spot tone", ASC);
 	gett("get_cw_spot_tone");
 
 	size_t p = replystr.rfind("EX020");
-	if (p == std::string::npos) return;
+	if (p == std::string::npos) return progStatus.cw_spot_tone;
 	replystr[p+7] = 0;
 	int n = atoi(&replystr[p+5]);
 	switch (n) {
@@ -1429,6 +1439,7 @@ void RIG_FT450D::get_cw_spot_tone()
 		case 7: case 8: progStatus.cw_spot_tone = 700; break;
 		case 9: default: progStatus.cw_spot_tone = 800; break;
 	}
+	return progStatus.cw_spot_tone;
 }
 
 void RIG_FT450D::get_vox_gain()
@@ -1464,7 +1475,6 @@ void RIG_FT450D::get_band_selection(int v)
 	sett("get band");
 }
 
-static int agcval = 0;
 int  RIG_FT450D::get_agc()
 {
     cmd = "GT0;";
