@@ -133,18 +133,34 @@ static const char *v60m[] = {"", "126", "127", "128", "130"};
 
 static std::vector<std::string>& Channels_60m = FT710_US_60m;
 
+//----------------------------------------------------------------------
+static std::vector<std::string>FT710_att_labels;
+static const char *vFT710_att_labels[] = { "ATT", "6 dB", "12 dB", "18 dB"};
+
+static std::vector<std::string>FT710_pre_labels;
+static const char *vFT710_pre_labels[] = { "IPO", "Amp 1", "Amp 2" };
+
+static std::vector<std::string>FT710_nb_labels;
+static const char *vFT710_nb_labels[] = { "NB", "NB on" };
+//----------------------------------------------------------------------
+
 static GUI rig_widgets[]= {
-	{ (Fl_Widget *)btnVol,        2, 125,  50 },
-	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },
-	{ (Fl_Widget *)sldrRFGAIN,   54, 145, 156 },
-	{ (Fl_Widget *)btnIFsh,     214, 105,  50 },
-	{ (Fl_Widget *)sldrIFSHIFT, 266, 105, 156 },
-	{ (Fl_Widget *)btnNotch,    214, 125,  50 },
-	{ (Fl_Widget *)sldrNOTCH,   266, 125, 156 },
-	{ (Fl_Widget *)sldrMICGAIN, 266, 145, 156 },
-	{ (Fl_Widget *)sldrPOWER,   266, 165, 156 },
-	{ (Fl_Widget *)btnNR,         2, 165,  50 },
-	{ (Fl_Widget *)sldrNR,       54, 165, 156 },
+	{ (Fl_Widget *)btnVol,        2, 125,  50 }, // 0
+	{ (Fl_Widget *)sldrVOLUME,   54, 125, 368 }, // 1
+	{ (Fl_Widget *)sldrRFGAIN,   54, 145, 156 }, // 2
+	{ (Fl_Widget *)sldrSQUELCH, 266, 145, 156 }, // 3
+
+	{ (Fl_Widget *)sldrMICGAIN,  54, 165, 156 }, // 4
+	{ (Fl_Widget *)btnNotch,    214, 165,  50 }, // 5
+	{ (Fl_Widget *)sldrNOTCH,   266, 165, 156 }, // 6
+
+	{ (Fl_Widget *)btnNR,         2, 185,  50 }, // 7
+	{ (Fl_Widget *)sldrNR,       54, 185, 156 }, // 8
+	{ (Fl_Widget *)btnIFsh,     214, 185,  50 }, // 9
+	{ (Fl_Widget *)sldrIFSHIFT, 266, 185, 156 }, // 10
+
+	{ (Fl_Widget *)sldrPOWER,    54, 205, 368 }, // 11
+
 	{ (Fl_Widget *)NULL,          0,   0,   0 }
 };
 
@@ -165,6 +181,15 @@ void RIG_FT710::initialize()
 	VECTOR(FT710_widths_DATA_FMN, vfmdn);
 	VECTOR(FT710_US_60m, v60m);
 
+	VECTOR (FT710_att_labels, vFT710_att_labels);
+	att_labels_ = FT710_att_labels;
+
+	VECTOR (FT710_pre_labels, vFT710_pre_labels);
+	pre_labels_ = FT710_pre_labels;
+
+	VECTOR (FT710_nb_labels, vFT710_nb_labels);
+	nb_labels_ = FT710_nb_labels;
+
 	modes_ = FT710modes_;
 	bandwidths_ = FT710_widths_SSB;
 	bw_vals_ = FT710_wvals_SSB;
@@ -172,14 +197,16 @@ void RIG_FT710::initialize()
 	rig_widgets[0].W = btnVol;
 	rig_widgets[1].W = sldrVOLUME;
 	rig_widgets[2].W = sldrRFGAIN;
-	rig_widgets[3].W = btnIFsh;
-	rig_widgets[4].W = sldrIFSHIFT;
+	rig_widgets[3].W = sldrSQUELCH;
+	rig_widgets[4].W = sldrMICGAIN;
 	rig_widgets[5].W = btnNotch;
 	rig_widgets[6].W = sldrNOTCH;
-	rig_widgets[7].W = sldrMICGAIN;
-	rig_widgets[8].W = sldrPOWER;
-	rig_widgets[9].W = btnNR;
-	rig_widgets[10].W = sldrNR;
+	rig_widgets[7].W = btnNR;
+	rig_widgets[8].W = sldrNR;
+	rig_widgets[9].W = btnIFsh;
+	rig_widgets[10].W = sldrIFSHIFT;
+	rig_widgets[11].W = sldrPOWER;
+
 
 	cmd = "AI0;";
 	sendCommand(cmd);
@@ -251,6 +278,7 @@ RIG_FT710::RIG_FT710() {
 	has_power_control =
 	has_volume_control =
 	has_rf_control =
+	has_sql_control =
 	has_micgain_control =
 	has_mode_control =
 	has_noise_control =
@@ -267,8 +295,8 @@ RIG_FT710::RIG_FT710() {
 	has_xcvr_auto_on_off = true;
 
 // derived specific
-	atten_level = 0;
-	preamp_level = 0;
+	atten_state = 0;
+	preamp_state = 0;
 	notch_on = false;
 	m_60m_indx = 0;
 
@@ -285,12 +313,9 @@ void RIG_FT710::set_xcvr_auto_on()
 {
 	cmd = "ID;";
 	wait_char(';', 7 , 100, "check", ASC);
-//std::cout << "check: " << replystr << std::endl;
 	if (replystr.find("ID") != std::string::npos)
 		return;
 
-//std::cout << "Xcvr not ON ... power ON cycle" << std::endl;
-
 // wait 1.2 seconds
 	for (int i = 0; i < 12; i++) {
 		MilliSleep(100);
@@ -298,40 +323,37 @@ void RIG_FT710::set_xcvr_auto_on()
 		Fl::awake();
 	}
 
-	cmd = "PS1;";
-//	std::cout << "power ON" << std::endl;
-	RigSerial->WriteBuffer(cmd.c_str(), cmd.length());
+	sendCommand("PS1;");
+	sett("set xcvr auto ON");
 
 	update_progress(0);
 
-// wait 7 seconds
-//	std::cout << "wait 10 seconds" << std::endl;
-	for (int i = 0; i < 140; i++) {
-		MilliSleep(50);
+// wait up to 10 seconds for normal response
+	cmd = "PS;";
+	for (int i = 0; i < 100; i++) {
+		wait_char(';', 4, 100, "Test for xcvr ON", ASC);
+		if (replystr.find("PS1;") != std::string::npos) {
+			update_progress(100);
+			break;
+		}
 		update_progress(i);
 		Fl::awake();
 	}
-	update_progress(0);
-
-//	std::cout << "restart serial port" << std::endl;
-
-	RigSerial->OpenPort();
-	cmd = "PS;";
-	wait_char(';', 4, 100, "closed/reopened port", ASC);
-	if (replystr.find("PS1;") == std::string::npos) {
-//		std::cout << "Reply to reopen port: " << replystr << std::endl;
-		exit(3);
-	}
-
-	return;
-
 }
 
 void RIG_FT710::set_xcvr_auto_off()
 {
-	cmd = "PS0;";
-	sendCommand(cmd);
+	sendCommand("PS0;");
 	sett("set_xcvr_auto_off");
+
+// transceiver does not respond after a power OFF
+
+	for (int i = 0; i < 100; i++) {
+		cmd = "PS;";
+		wait_char(';', 4, 100, "Test for xcvr OFF", ASC);
+		if (replystr.empty()) break;
+		Fl::awake();
+	}
 }
 
 void RIG_FT710::get_band_selection(int v)
@@ -557,11 +579,9 @@ int RIG_FT710::get_swr()
 	return mtr / 2.56;
 }
 
-struct mtrpair {int mtr; float val;};
-
 double RIG_FT710::get_idd()
 {
-	static mtrpair iddtbl[] = {
+	static meterpair iddtbl[] = {
 		{ 52, 5.0 },
 		{ 70, 7.0 },
 		{ 96, 10.0 },
@@ -586,7 +606,7 @@ double RIG_FT710::get_idd()
 	if (p != std::string::npos) {
 		sscanf(&replystr[p], "RM7%3d%3d", &mtr, &dmy);
 		size_t i = 0;
-		for (i = 0; i < sizeof(iddtbl) / sizeof(mtrpair) - 1; i++)
+		for (i = 0; i < sizeof(iddtbl) / sizeof(meterpair) - 1; i++)
 			if (mtr >= iddtbl[i].mtr && mtr < iddtbl[i+1].mtr)
 				break;
 		if (mtr < 0) mtr = 0;
@@ -623,7 +643,7 @@ double RIG_FT710::get_voltmeter()
 
 int RIG_FT710::get_power_out()
 {
-	static mtrpair pwrtbl[] = { 
+	static meterpair pwrtbl[] = { 
 		{ 35,  5.0 },
 		{ 94, 25.0 },
 		{147, 50.0 },
@@ -642,7 +662,7 @@ int RIG_FT710::get_power_out()
 	sscanf(&replystr[p], "RM5%3d%3d", &mtr, &dmy);
 
 	size_t i = 0;
-	for (i = 0; i < sizeof(pwrtbl) / sizeof(mtrpair) - 1; i++)
+	for (i = 0; i < sizeof(pwrtbl) / sizeof(meterpair) - 1; i++)
 		if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
 			break;
 	if (mtr < 0) mtr = 0;
@@ -790,7 +810,7 @@ int RIG_FT710::get_tune()
 
 int  RIG_FT710::next_attenuator()
 {
-	switch (atten_level) {
+	switch (atten_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 3;
@@ -801,9 +821,9 @@ int  RIG_FT710::next_attenuator()
 
 void RIG_FT710::set_attenuator(int val)
 {
-	atten_level = val;
+	atten_state = val;
 	cmd = "RA00;";
-	cmd[3] += atten_level;
+	cmd[3] += atten_state;
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET att", cmd, replystr);
 }
@@ -819,13 +839,13 @@ int RIG_FT710::get_attenuator()
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
-	atten_level = replystr[p+3] - '0';
-	return atten_level;
+	atten_state = replystr[p+3] - '0';
+	return atten_state;
 }
 
 int  RIG_FT710::next_preamp()
 {
-	switch (preamp_level) {
+	switch (preamp_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 0;
@@ -835,9 +855,9 @@ int  RIG_FT710::next_preamp()
 
 void RIG_FT710::set_preamp(int val)
 {
-	preamp_level = val;
+	preamp_state = val;
 	cmd = "PA00;";
-	cmd[3] = '0' + preamp_level;
+	cmd[3] = '0' + preamp_state;
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET preamp", cmd, replystr);
 }
@@ -852,28 +872,8 @@ int RIG_FT710::get_preamp()
 
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos)
-		preamp_level = replystr[p+3] - '0';
-	return preamp_level;
-}
-
-const char *RIG_FT710::ATT_label()
-{
-	if (atten_level == 1)
-		return "6 dB";
-	if (atten_level == 2)
-		return "12 dB";
-	if (atten_level == 3)
-		return "18 dB";
-	return "ATT";
-}
-
-const char *RIG_FT710::PRE_label()
-{
-	if (preamp_level == 1)
-		return "Amp 1";
-	if (preamp_level == 2)
-		return "Amp 2";
-	return "IPO";
+		preamp_state = replystr[p+3] - '0';
+	return preamp_state;
 }
 
 static bool narrow = 0; // 0 - wide, 1 - narrow
@@ -1304,8 +1304,6 @@ int  RIG_FT710::get_auto_notch()
 	return 0;
 }
 
-int FT710_blanker_level = 0;
-
 void RIG_FT710::set_noise(bool b)
 {
 	if (inuse == onB)
@@ -1313,11 +1311,13 @@ void RIG_FT710::set_noise(bool b)
 	else
 		cmd = "NB00;";
 
+	nb_state = b;
+
 	if (b) {
 		cmd[3] = '1';
-		nb_label("NB on", true);
+		noise_blanker_label(nb_label(), true);
 	} else
-		nb_label("NB", false);
+		noise_blanker_label(nb_label(), false);
 
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET NB", cmd, replystr);
@@ -1332,16 +1332,16 @@ int RIG_FT710::get_noise()
 	gett("get_noise()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == std::string::npos) return FT710_blanker_level;
+	if (p == std::string::npos) return nb_state;
 
-	FT710_blanker_level = replystr[p+3] - '0';
+	nb_state = replystr[p+3] - '0';
 
-	if (FT710_blanker_level) {
-		nb_label("NB on", true);
+	if (nb_state) {
+		noise_blanker_label("NB on", true);
 	} else
-		nb_label("NB", false);
+		noise_blanker_label("NB", false);
 
-	return FT710_blanker_level;
+	return nb_state;
 }
 
 // val 0 .. 100
@@ -1600,3 +1600,35 @@ void RIG_FT710::sync_clock(char *tm)
 	sett("sync_time");
 }
 
+void RIG_FT710::set_squelch(int val)
+{
+	cmd = "SQ0000;";
+	for (int i = 5; i > 2; i--) {
+		cmd[i] = val % 10 + '0';
+		val /= 10;
+	}
+
+	set_trace(1, "set_squelch()");
+	sendCommand(cmd);
+	sett("");
+	showresp(WARN, ASC, "SET squelch", cmd, replystr);
+}
+
+int  RIG_FT710::get_squelch()
+{
+	int sqval = 0;
+	cmd = rsp = "SQ0";
+	cmd += ';';
+	get_trace(1, "get_squelch()");
+	wait_char(';',7, 100, "get squelch", ASC);
+	gett("");
+
+	size_t p = replystr.rfind(rsp);
+	if (p == std::string::npos) return progStatus.squelch;
+	for (int i = 3; i < 6; i++) {
+		sqval *= 10;
+		sqval += replystr[p+i] - '0';
+	}
+	return ceil(sqval);
+}
+
