@@ -137,6 +137,17 @@ static const char *vFTdx10_US_60m[] = {"", "126", "127", "128", "130"};
 
 static std::vector<std::string>& Channels_60m = FTdx10_US_60m;
 
+//----------------------------------------------------------------------
+static std::vector<std::string>FTdx10_att_labels;
+static const char *vFTdx10_att_labels[] = { "ATT", "6 dB", "12 dB", "18 dB"};
+
+static std::vector<std::string>FTdx10_pre_labels;
+static const char *vFTdx10_pre_labels[] = { "IPO", "Amp 1", "Amp 2"};
+
+static std::vector<std::string>FTdx10_nb_labels;
+static const char *vFTdx10_nb_labels[] = { "NB", "NB on" };
+//----------------------------------------------------------------------
+
 static GUI rig_widgets[]= {
 	{ (Fl_Widget *)btnVol,        2, 125,  50 },
 	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },
@@ -171,6 +182,15 @@ void RIG_FTdx10::initialize()
 	bandwidths_ = FTdx10_widths_SSB;
 	bw_vals_ = FTdx10_wvals_SSB;
 
+	VECTOR (FTdx10_att_labels, vFTdx10_att_labels);
+	att_labels_ = FTdx10_att_labels;
+
+	VECTOR (FTdx10_pre_labels, vFTdx10_pre_labels);
+	pre_labels_ = FTdx10_pre_labels;
+
+	VECTOR (FTdx10_nb_labels, vFTdx10_nb_labels);
+	nb_labels_ = FTdx10_nb_labels;
+
 	rig_widgets[0].W = btnVol;
 	rig_widgets[1].W = sldrVOLUME;
 	rig_widgets[2].W = sldrRFGAIN;
@@ -267,8 +287,8 @@ RIG_FTdx10::RIG_FTdx10() {
 	has_xcvr_auto_on_off = true;
 
 // derived specific
-	atten_level = 0;
-	preamp_level = 0;
+	atten_state = 0;
+	preamp_state = 0;
 	notch_on = false;
 	m_60m_indx = 0;
 
@@ -564,11 +584,9 @@ int RIG_FTdx10::get_swr()
 	return mtr / 2.56;
 }
 
-struct pwrpair {int mtr; float pwr;};
-
 int RIG_FTdx10::get_power_out()
 {
-	static pwrpair pwrtbl[] = { 
+	static meterpair pwrtbl[] = { 
 		{ 35,  5.0 },
 		{ 94, 25.0 },
 		{147, 50.0 },
@@ -587,13 +605,13 @@ int RIG_FTdx10::get_power_out()
 	int mtr = atoi(replystr.substr(p + 3, 3).c_str());
 
 	size_t i = 0;
-	for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
+	for (i = 0; i < sizeof(pwrtbl) / sizeof(meterpair) - 1; i++)
 		if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
 			break;
 	if (mtr < 0) mtr = 0;
 	if (mtr > 205) mtr = 205;
-	double pwr = (int)ceil(pwrtbl[i].pwr + 
-			  (pwrtbl[i+1].pwr - pwrtbl[i].pwr)*(mtr - pwrtbl[i].mtr) / (pwrtbl[i+1].mtr - pwrtbl[i].mtr));
+	double pwr = (int)ceil(pwrtbl[i].val + 
+			  (pwrtbl[i+1].val - pwrtbl[i].val)*(mtr - pwrtbl[i].mtr) / (pwrtbl[i+1].mtr - pwrtbl[i].mtr));
 
 	if (pwr > 100) pwr = 100;
 
@@ -615,11 +633,9 @@ int RIG_FTdx10::get_alc()
 	return (int)ceil(mtr / 2.56);
 }
 
-struct mtrpair {int mtr; float val;};
-
 double RIG_FTdx10::get_idd()
 {
-	static mtrpair iddtbl[] = {
+	static meterpair iddtbl[] = {
 		{ 52, 5.0 },
 		{ 70, 7.0 },
 		{ 96, 10.0 },
@@ -644,7 +660,7 @@ double RIG_FTdx10::get_idd()
 	if (p != std::string::npos) {
 		sscanf(&replystr[p], "RM7%3d%3d", &mtr, &dmy);
 		size_t i = 0;
-		for (i = 0; i < sizeof(iddtbl) / sizeof(mtrpair) - 1; i++)
+		for (i = 0; i < sizeof(iddtbl) / sizeof(meterpair) - 1; i++)
 			if (mtr >= iddtbl[i].mtr && mtr < iddtbl[i+1].mtr)
 				break;
 		if (mtr < 0) mtr = 0;
@@ -796,7 +812,7 @@ int RIG_FTdx10::get_tune()
 
 int  RIG_FTdx10::next_attenuator()
 {
-	switch (atten_level) {
+	switch (atten_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 3;
@@ -807,9 +823,9 @@ int  RIG_FTdx10::next_attenuator()
 
 void RIG_FTdx10::set_attenuator(int val)
 {
-	atten_level = val;
+	atten_state = val;
 	cmd = "RA00;";
-	cmd[3] += atten_level;
+	cmd[3] += atten_state;
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET att", cmd, replystr);
 }
@@ -825,13 +841,13 @@ int RIG_FTdx10::get_attenuator()
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
-	atten_level = replystr[p+3] - '0';
-	return atten_level;
+	atten_state = replystr[p+3] - '0';
+	return atten_state;
 }
 
 int  RIG_FTdx10::next_preamp()
 {
-	switch (preamp_level) {
+	switch (preamp_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 0;
@@ -841,9 +857,9 @@ int  RIG_FTdx10::next_preamp()
 
 void RIG_FTdx10::set_preamp(int val)
 {
-	preamp_level = val;
+	preamp_state = val;
 	cmd = "PA00;";
-	cmd[3] = '0' + preamp_level;
+	cmd[3] = '0' + preamp_state;
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET preamp", cmd, replystr);
 }
@@ -858,28 +874,8 @@ int RIG_FTdx10::get_preamp()
 
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos)
-		preamp_level = replystr[p+3] - '0';
-	return preamp_level;
-}
-
-const char *RIG_FTdx10::ATT_label()
-{
-	if (atten_level == 1)
-		return "6 dB";
-	if (atten_level == 2)
-		return "12 dB";
-	if (atten_level == 3)
-		return "18 dB";
-	return "ATT";
-}
-
-const char *RIG_FTdx10::PRE_label()
-{
-	if (preamp_level == 1)
-		return "Amp 1";
-	if (preamp_level == 2)
-		return "Amp 2";
-	return "IPO";
+		preamp_state = replystr[p+3] - '0';
+	return preamp_state;
 }
 
 static bool narrow = 0; // 0 - wide, 1 - narrow
@@ -1310,8 +1306,6 @@ int  RIG_FTdx10::get_auto_notch()
 	return 0;
 }
 
-int FTdx10_blanker_level = 0;
-
 void RIG_FTdx10::set_noise(bool b)
 {
 	if (inuse == onB)
@@ -1319,11 +1313,12 @@ void RIG_FTdx10::set_noise(bool b)
 	else
 		cmd = "NB00;";
 
+	nb_state = b;
 	if (b) {
 		cmd[3] = '1';
-		nb_label("NB on", true);
+		noise_blanker_label(nb_label(), true);
 	} else
-		nb_label("NB", false);
+		noise_blanker_label(nb_label(), false);
 
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET NB", cmd, replystr);
@@ -1338,16 +1333,16 @@ int RIG_FTdx10::get_noise()
 	gett("get_noise()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == std::string::npos) return FTdx10_blanker_level;
+	if (p == std::string::npos) return nb_level;
 
-	FTdx10_blanker_level = replystr[p+3] - '0';
+	nb_state = replystr[p+3] - '0';
 
-	if (FTdx10_blanker_level) {
-		nb_label("NB on", true);
+	if (nb_state) {
+		noise_blanker_label(nb_label(), true);
 	} else
-		nb_label("NB", false);
+		noise_blanker_label(nb_label(), false);
 
-	return FTdx10_blanker_level;
+	return nb_state;
 }
 
 // val 0 .. 100
