@@ -124,6 +124,17 @@ static const char *vFTdx3000_US_60m[] = {"", "126", "127", "128", "130"};
 
 static std::vector<std::string>& Channels_60m = FTdx3000_US_60m;
 
+//----------------------------------------------------------------------
+static std::vector<std::string>FTdx3000_att_labels;
+static const char *vFTdx3000_att_labels[] = { "ATT", "6 dB", "12 dB", "18 dB"};
+
+static std::vector<std::string>FTdx3000_pre_labels;
+static const char *vFTdx3000_pre_labels[] = { "IPO", "Amp 1", "Amp 2"};
+
+static std::vector<std::string>FTdx3000_nb_labels;
+static const char *vFTdx3000_nb_labels[] = { "NB", "NB 1", "NB 2" };
+//----------------------------------------------------------------------
+
 static GUI rig_widgets[]= {
 	{ (Fl_Widget *)btnVol,        2, 125,  50 },
 	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },
@@ -151,6 +162,15 @@ void RIG_FTdx3000::initialize()
 	VECTOR (FTdx3000_widths_FMpkt, vFTdx3000_widths_FMpkt);
 	VECTOR (FTdx3000_US_60m, vFTdx3000_US_60m);
 
+	VECTOR (FTdx3000_att_labels, vFTdx3000_att_labels);
+	att_labels_ = FTdx3000_att_labels;
+
+	VECTOR (FTdx3000_pre_labels, vFTdx3000_pre_labels);
+	pre_labels_ = FTdx3000_pre_labels;
+
+	VECTOR (FTdx3000_nb_labels, vFTdx3000_nb_labels);
+	nb_labels_ = FTdx3000_nb_labels;
+
 	modes_ = FTdx3000modes_;
 	bandwidths_ = FTdx3000_widths_SSB;
 	bw_vals_ = FTdx3000_wvals_SSB;
@@ -244,8 +264,8 @@ RIG_FTdx3000::RIG_FTdx3000() {
 	has_tune_control = true;
 
 // derived specific
-	atten_level = 0;
-	preamp_level = 0;
+	atten_state = 0;
+	preamp_state = 0;
 	notch_on = false;
 	m_60m_indx = 0;
 
@@ -451,9 +471,7 @@ int RIG_FTdx3000::get_swr()
 	return mtr / 2.56;
 }
 
-struct pwrpair {int mtr; float pwr;};
-
-static pwrpair pwrtbl[] = { 
+static meterpair pwrtbl[] = { 
 { 32,  5.0 },
 { 53, 10.0 },
 { 80, 20.0 },
@@ -480,13 +498,13 @@ int RIG_FTdx3000::get_power_out()
 	if (p + 6 >= replystr.length()) return 0;
 	int mtr = atoi(&replystr[p+3]);
 	size_t i = 0;
-	for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
+	for (i = 0; i < sizeof(pwrtbl) / sizeof(meterpair) - 1; i++)
 		if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
 			break;
 	if (mtr < 0) mtr = 0;
 	if (mtr > 197) mtr = 197;
-	int pwr = (int)ceil(pwrtbl[i].pwr + 
-			  (pwrtbl[i+1].pwr - pwrtbl[i].pwr)*(mtr - pwrtbl[i].mtr) / (pwrtbl[i+1].mtr - pwrtbl[i].mtr));
+	int pwr = (int)ceil(pwrtbl[i].val + 
+			  (pwrtbl[i+1].val - pwrtbl[i].val)*(mtr - pwrtbl[i].mtr) / (pwrtbl[i+1].mtr - pwrtbl[i].mtr));
 
 	if (pwr > 100) pwr = 100;
 
@@ -625,7 +643,7 @@ int RIG_FTdx3000::get_tune()
 
 int  RIG_FTdx3000::next_attenuator()
 {
-	switch (atten_level) {
+	switch (atten_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 3;
@@ -636,10 +654,10 @@ int  RIG_FTdx3000::next_attenuator()
 
 void RIG_FTdx3000::set_attenuator(int val)
 {
-	atten_level = val;
+	atten_state = val;
 
 	cmd = "RA00;";
-	cmd[3] += atten_level;
+	cmd[3] += atten_state;
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET att", cmd, replystr);
 }
@@ -655,13 +673,13 @@ int RIG_FTdx3000::get_attenuator()
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
-	atten_level = replystr[p+3] - '0';
-	return atten_level;
+	atten_state = replystr[p+3] - '0';
+	return atten_state;
 }
 
 int  RIG_FTdx3000::next_preamp()
 {
-	switch (preamp_level) {
+	switch (preamp_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 0;
@@ -671,10 +689,10 @@ int  RIG_FTdx3000::next_preamp()
 
 void RIG_FTdx3000::set_preamp(int val)
 {
-	preamp_level = val;
+	preamp_state = val;
 	cmd = "PA00;";
 
-	cmd[3] = '0' + preamp_level;
+	cmd[3] = '0' + preamp_state;
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET preamp", cmd, replystr);
 }
@@ -689,28 +707,8 @@ int RIG_FTdx3000::get_preamp()
 
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos)
-		preamp_level = replystr[p+3] - '0';
-	return preamp_level;
-}
-
-const char *RIG_FTdx3000::ATT_label()
-{
-	if (atten_level == 1)
-		return "6 dB";
-	if (atten_level == 2)
-		return "12 dB";
-	if (atten_level == 3)
-		return "18 dB";
-	return "ATT";
-}
-
-const char *RIG_FTdx3000::PRE_label()
-{
-	if (preamp_level == 1)
-		return "Amp 1";
-	if (preamp_level == 2)
-		return "Amp 2";
-	return "IPO";
+		preamp_state = replystr[p+3] - '0';
+	return preamp_state;
 }
 
 int RIG_FTdx3000::adjust_bandwidth(int val)
@@ -1107,22 +1105,20 @@ int  RIG_FTdx3000::get_auto_notch()
 	return 0;
 }
 
-int FTdx3000_blanker_level = 0;
-
 void RIG_FTdx3000::set_noise(bool b)
 {
 	cmd = "NB00;";
-	if (FTdx3000_blanker_level == 0) {
-		FTdx3000_blanker_level = 1;
-		nb_label("NB 1", true);
-	} else if (FTdx3000_blanker_level == 1) {
-		FTdx3000_blanker_level = 2;
-		nb_label("NB 2", true);
-	} else if (FTdx3000_blanker_level == 2) {
-		FTdx3000_blanker_level = 0;
-		nb_label("NB", false);
+	if (nb_state == 0) {
+		nb_state = 1;
+		noise_blanker_label(nb_label(), true);
+	} else if (nb_state == 1) {
+		nb_state = 2;
+		noise_blanker_label(nb_label(), true);
+	} else if (nb_state == 2) {
+		nb_state = 0;
+		noise_blanker_label(nb_label(), false);
 	}
-	cmd[3] = '0' + FTdx3000_blanker_level;
+	cmd[3] = '0' + nb_state;
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET NB", cmd, replystr);
 }
@@ -1136,18 +1132,18 @@ int RIG_FTdx3000::get_noise()
 	gett("get_noise()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == std::string::npos) return FTdx3000_blanker_level;
+	if (p == std::string::npos) return nb_state;
 
-	FTdx3000_blanker_level = replystr[p+3] - '0';
-	if (FTdx3000_blanker_level == 1) {
-		nb_label("NB 1", true);
-	} else if (FTdx3000_blanker_level == 2) {
-		nb_label("NB 2", true);
+	nb_state = replystr[p+3] - '0';
+	if (nb_state == 1) {
+		noise_blanker_label(nb_label(), true);
+	} else if (nb_state == 2) {
+		noise_blanker_label(nb_label(), true);
 	} else {
-		nb_label("NB", false);
-		FTdx3000_blanker_level = 0;
+		noise_blanker_label(nb_label(), false);
+		nb_state = 0;
 	}
-	return FTdx3000_blanker_level;
+	return nb_state;
 }
 
 // val 0 .. 100
