@@ -45,8 +45,6 @@ void TRACED(adjust_small_ui)
 
 	int y = 0;
 
-//	mainwindow->resize( mainwindow->x(), mainwindow->y(), SMALL_MAINW, SMALL_MAINH);
-
 	btnVol->hide();
 	sldrVOLUME->hide();
 	sldrRFGAIN->hide();
@@ -302,13 +300,14 @@ void TRACED(adjust_small_ui)
 	}
 
 	int sX, sY, sW, sH;
-	sX = mainwindow->x();
-	sY = mainwindow->y();
+	sX = progStatus.mainX;//mainwindow->x();
+	sY = progStatus.mainY;//mainwindow->y();
 	sW = mainwindow->w();
 	sH = btn_show_controls->y() + btn_show_controls->h() + 2;
 
 	mainwindow->resize( sX, sY, sW, sH);
 	mainwindow->size_range( sW, sH, sW, sH);
+
 	progStatus.mainX = mainwindow->x();
 	progStatus.mainY = mainwindow->y();
 	progStatus.mainW = mainwindow->w();
@@ -826,7 +825,8 @@ void TRACED(init_Generic_Tabs)
 		selrig->has_cw_weight ||
 		selrig->has_cw_keyer ||
 		selrig->has_cw_spot ||
-		selrig->has_cw_spot_tone ) {
+		selrig->has_cw_spot_tone ||
+		selrig->has_cw_vol ) {
 
 		if (selrig->has_cw_wpm) {
 			int min, max;
@@ -883,7 +883,7 @@ void TRACED(init_Generic_Tabs)
 			spnr_cw_vol->minimum(min);
 			spnr_cw_vol->maximum(max);
 			spnr_cw_vol->step(step);
-			selrig->get_cw_vol();
+			progStatus.cw_vol = selrig->get_cw_vol();
 			spnr_cw_vol->value(progStatus.cw_vol);
 		} else
 			spnr_cw_vol->hide();
